# IQ Tools

# Build Instructions

1. Clone the repo: `git clone git@github.com:loganrf/IQtools.git`
2. Install dependencies: `poetry install`
3. Build: `poetry build`

# Example Run Instructions
1. Follow steps 1/2 from **Build Instructions** above
2. Run `poetry run python main.py`
